Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type MultiItemList ¶
type MultiItemList struct {
runtime.ComponentBase
Items []Item
}
MultiItemList demonstrates trackBy with multiple sibling child elements per loop iteration. This tests a critical compiler edge case where multiple children in a loop body previously caused variable shadowing errors.
func (*MultiItemList) AddItem ¶
func (m *MultiItemList) AddItem(name string)
func (*MultiItemList) ClearItems ¶
func (m *MultiItemList) ClearItems()
func (*MultiItemList) OnMount ¶
func (m *MultiItemList) OnMount()
type ProductList ¶
type ProductList struct {
runtime.ComponentBase
Products []Product
}
ProductList demonstrates trackBy with struct slice using dot-notation
func (*ProductList) AddProduct ¶
func (p *ProductList) AddProduct(name string)
func (*ProductList) ClearProducts ¶
func (p *ProductList) ClearProducts()
func (*ProductList) OnMount ¶
func (p *ProductList) OnMount()
type TagList ¶
type TagList struct {
runtime.ComponentBase
Tags []string
}
TagList demonstrates trackBy with primitive string slice
Click to show internal directories.
Click to hide internal directories.